# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-03-02 11:37
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('hurumap', '0002_geography_long_name'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='geography',
            name='osm_area_id',
        ),
    ]
