{% extends '_base.html' %}{% load humanize %}

{% block head_title %}{{ block.super }}{% endblock %}

{% block content %}
<article id="welcome">
    <header>
        <h1>Not Found</h1>
        {% for message in messages %}
            <p class="message display-type clearfix"><span{% if message.tags %} class="message-{{ message.tags }}"{% endif %}>{{ message|safe }}</span></p>
        {% endfor %}
    </header>
    <section class="column-golden-narrow">
        <p>In the spirit of open and iterative development, we&rsquo;re making this site available to the public as early as possible. Much will change, and some things may not be working at any moment, but we want people to see what we&rsquo;re working on and we welcome input about what might be most useful. (See below for all manner of contact information.)</p>
    </section>
{% endblock %}