<section id="explore-topic-picker" class="column-full clearfix big-action">
    <h1 class="article-header">Find data</h1>
    <p class="primary-explainer">Use keywords to search {{ HURUMAP.name }} for data, then choose a place or places to view your data.</p>
    
    <div id="topic-select-wrapper" class="input-wrapper">
        <input name="topic_select" id="topic-select" type="text" placeholder="Find a dataset. Try searching for age or gender" autocomplete="off">
    </div>
</section>
<section id="explore-topic-place-picker" class="column-full clearfix big-action">
    <h1 class="article-header article-header-right">in</h1>
    <div id="topic-place-select-wrapper" class="input-wrapper">
        <input name="topic_place_select" id="topic-place-select" type="text" placeholder="Choose a place or geographic summary level..." autocomplete="off">
        <p class="help-text">Find a place to explore data, or choose a geographic summary level to build a comparison.</p>
    </div>
</section>
<section id="explore-topic-place-picker-parent" class="column-full clearfix big-action">
    <h1 class="article-header article-header-right">in</h1>
    <div id="topic-place-select-wrapper-parent" class="input-wrapper">
        <input name="topic_place_select_parent" id="topic-place-select-parent" type="text" placeholder="Start typing to pick a place to explore..." autocomplete="off">
        <p class="help-text"></p>
    </div>
</section>
